Now work on the next stage of the planning doc (prioritising work suggested by the user).

If the planning doc is currently stored in `planning/later/` or `planning/discarded/`, first move it to `planning/` (to signal that it's in progress).

Start by reading relevant code & docs.

Ask if you need to clarify anything, or if you have concerns.

Use tasks and subagents (provided with lots of context), e.g. for curl/Puppeteer/Playwright MCP (preferring Puppeteer), running tests, and any other encapsulated tasks. Follow instructions in TASKS_SUBAGENTS.md

Always stop to review with the user at the end of a stage. If a stage is massive, then stop partway through. Output as per DEBRIEF_PROGRESS.md